DatabaseStateMachine

Struct DatabaseStateMachine 

pub struct DatabaseStateMachine<F: DatabaseOperationHandler> { /* private fields */ }
A state machine that delegates operations to the actual database storage. This allows Raft to replicate real database operations.

Implementations

Source

impl<F: DatabaseOperationHandler> DatabaseStateMachine<F>

pub fn new(handler: F) -> Self

Create a new database state machine with the given operation handler.